Skip to main contentModule config
Source - LoadedConfig
- A configuration plus the provenance needed to enforce monotonic project
policy and explain the final profile.
- ProfileConfig
- A single profile configuration block from the YAML file.
- SandboxPath
- A path with an explicit kind for SBPL generation.
- SbeConfig
- Top-level configuration file structure (
.sbe.yaml or ~/.config/sbe/config.yaml).
- ConfigOrigin
- Trust provenance of a loaded configuration file.
- PathKind
- How a
SandboxPath should be matched in SBPL.
- expand_path
- Expand path placeholders and detect directory vs file from trailing
/. - load_configs
- Load and merge configuration from all sources.
- resolve_profile
- Resolve the final
SandboxProfile by merging configs into the ecosystem default.