Module profile

Module profile 

Structs

DomainPattern
A pattern for matching domain names.
ProfileOverrides
Overrides from CLI flags that get merged into the resolved profile.
SandboxProfile
The resolved set of sandbox permissions for a single execution.