Module profile
sbe_
core
0.3.2
Module profile
Module Items
Structs
In crate sbe_
core
sbe_core
Module
profile
Structs

Domain
Pattern
A pattern for matching domain names.
Profile
Overrides
Overrides from CLI flags that get merged into the resolved profile.
Sandbox
Profile
The resolved set of sandbox permissions for a single execution.